@@ -2,11 +2,11 @@
 An interface to the python-swiftclient api through Django.
 """
 __version_info__ = {
-    'major': 1,
-    'minor': 0,
-    'micro': 11,
-    'releaselevel': 'final',
-    'serial': 1
+    "major": 1,
+    "minor": 0,
+    "micro": 12,
+    "releaselevel": "final",
+    "serial": 1
 }
 
 
